#[non_exhaustive]pub enum FallbackReason {
OverlapConflict,
ValidatorVeto,
AnchorMissing,
ResidualSuspect,
}Expand description
Safety-net fallback reason recorded in metadata-only audit rows.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OverlapConflict
The suspect overlapped an existing emitted token in a way that could not be promoted.
ValidatorVeto
A validator rejected the promoted candidate.
AnchorMissing
A mandatory anchor was missing for the promoted candidate.
ResidualSuspect
A follow-up safety-net pass still observed a suspect.