CodecCapabilitySet

Struct CodecCapabilitySet 

#[non_exhaustive]
pub struct CodecCapabilitySet { pub text: bool, pub layout: bool, pub confidence: bool, pub timestamps: bool, }
Orthogonal document codec capabilities delivered or advertised by a codec.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
text: bool

Codec can emit text.

layout: bool

Codec can emit layout geometry.

confidence: bool

Codec can emit confidence buckets.

timestamps: bool

Codec can emit timestamps.

Implementations

Source

impl CodecCapabilitySet

pub const TEXT_ONLY: Self

Text-only capability set.

pub const fn new( text: bool, layout: bool, confidence: bool, timestamps: bool, ) -> Self

Builds a codec capability bitset.

pub fn contains(self, requested: Self) -> bool

Returns true when this set contains every requested capability bit.