#[non_exhaustive]pub enum ValidatorKindParseError {
UnsupportedValidator {
kind: String,
},
}Expand description
Error returned when a rulepack names a validator unsupported by this build.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedValidator
Validator kind is not known or is gated behind a disabled feature.